@@ -17,7 +17,7 @@
  */
 
 /**
- * @file ipc.c
+ * @file
  * @brief Inter-process communitcation (IPC)
  */
 
@@ -74,6 +74,8 @@ init_semaphore_set ()
   gchar *key_file_name = g_build_filename (GVM_STATE_DIR, "gvmd.sem", NULL);
   FILE *key_file = fopen (key_file_name, "a");
   union semun sem_value;
+  struct semid_ds sem_info;
+
   if (key_file == NULL)
     {
       g_warning ("%s: error creating semaphore file %s: %s",
@@ -82,7 +84,7 @@ init_semaphore_set ()
       return -1;
     }
   fclose (key_file);
-  semaphore_set_key = ftok (key_file_name, 0);
+  semaphore_set_key = ftok (key_file_name, 42);
   if (semaphore_set_key < 0)
     {
       g_warning ("%s: error creating semaphore key for file %s: %s",
@@ -91,7 +93,46 @@ init_semaphore_set ()
       return -1;
     }
 
-  semaphore_set = semget (semaphore_set_key, 1, 0660 | IPC_CREAT);
+  semaphore_set = semget (semaphore_set_key, 0, 0);
+  if (semaphore_set < 0)
+    {
+      if (errno != ENOENT)
+        {
+          g_warning ("%s: error getting existing semaphore set: %s",
+                    __func__, strerror (errno));
+          g_free (key_file_name);
+          return -1;
+        }
+      g_debug ("%s: semaphore set does not exist, creating new one", __func__);
+    }
+  else
+    {
+      if (semctl (semaphore_set, 0, IPC_STAT, &sem_info) == -1)
+        {
+          g_warning ("%s: error getting semaphore set info: %s",
+                    __func__, strerror (errno));
+          g_free (key_file_name);
+          return -1;
+        }
+      if (sem_info.sem_nsems != SEMAPHORE_SET_SIZE)
+        {
+          g_debug ("%s: semaphore set has %lu semaphores, expected %d.",
+                     __func__, sem_info.sem_nsems, SEMAPHORE_SET_SIZE);
+          g_debug ("%s: removing existing semaphore set", __func__);
+          int ret = semctl (semaphore_set, 0, IPC_RMID);
+          if (ret == -1)
+            {
+              g_warning ("%s: error removing existing semaphore set: %s",
+                        __func__, strerror (errno));
+              g_free (key_file_name);
+              return -1;
+            }
+        }
+    }
+
+  semaphore_set 
+    = semget (semaphore_set_key, SEMAPHORE_SET_SIZE, 0660 | IPC_CREAT);
+
   if (semaphore_set < 0)
     {
       g_warning ("%s: error getting semaphore set: %s",
@@ -112,6 +153,62 @@ init_semaphore_set ()
       return -1;
     }
 
+  sem_value.val = get_max_database_connections ()
+                  ?: MAX_DATABASE_CONNECTIONS_DEFAULT;
+
+  if (semctl (semaphore_set,
+              SEMAPHORE_DB_CONNECTIONS,
+              SETVAL, sem_value) == -1)
+    {
+      g_warning ("%s: error initializing database connections semaphore: %s",
+                 __func__, strerror (errno));
+      return -1;
+    }
+
+  sem_value.val = get_max_concurrent_report_processing ()
+                  ?: MAX_REPORT_PROCESSING_DEFAULT;
+
+  if (semctl (semaphore_set,
+              SEMAPHORE_REPORTS_PROCESSING,
+              SETVAL, sem_value) == -1)
+    {
+      g_warning ("%s: error initializing reports processing semaphore: %s",
+                  __func__, strerror (errno));
+      return -1;
+    }
+
+  return 0;
+}
+
+/**
+ * @brief Reinitializes the semaphore set.
+ *
+ * @return 0 success, -1 error
+ */
+int
+reinit_semaphore_set ()
+{
+  gchar *key_file_name = g_build_filename (GVM_STATE_DIR, "gvmd.sem", NULL);
+
+  semaphore_set_key = ftok (key_file_name, 42);
+
+  if (semaphore_set_key < 0)
+    {
+      g_warning ("%s: error creating semaphore key for file %s: %s",
+                 __func__, key_file_name, strerror (errno));
+      g_free (key_file_name);
+      return -1;
+    }
+  g_free (key_file_name);
+
+  semaphore_set = semget (semaphore_set_key, 0, 0);
+
+  if (semaphore_set < 0)
+    {
+      g_warning ("%s: error getting semaphore set: %s",
+                 __func__, strerror (errno));
+      return -1;
+    }
   return 0;
 }
 
