@@ -56,10 +56,15 @@
 
 #if ENABLE_AGENTS
 #include <gvm/agent_controller/agent_controller.h>
+#include "manage_agent_control_scan_config.h"
 #include "manage_agent_groups.h"
 #include "manage_agents.h"
 #endif
 
+#if ENABLE_CONTAINER_SCANNING
+#include "manage_oci_image_targets.h"
+#endif
+
 /**
  * @brief OID of ping_host.nasl
  */
@@ -341,7 +346,8 @@ typedef enum scanner_type
   SCANNER_TYPE_AGENT_CONTROLLER = 7,
   SCANNER_TYPE_OPENVASD_SENSOR = 8,
   SCANNER_TYPE_AGENT_CONTROLLER_SENSOR = 9,
-  SCANNER_TYPE_MAX = 10,
+  SCANNER_TYPE_CONTAINER_IMAGE = 10,
+  SCANNER_TYPE_MAX = 11,
 } scanner_type_t;
 
 int
@@ -350,6 +356,12 @@ scanner_type_valid (scanner_type_t);
 int
 scanner_type_supports_unix_sockets (scanner_type_t);
 
+scanner_type_t
+get_scanner_type (scanner_t);
+
+scanner_type_t
+get_scanner_type_by_uuid (const char *);
+
 
 /* Resources. */
 
@@ -621,6 +633,19 @@ int
 set_task_schedule_and_periods (task_t task, const gchar *schedule_id,
                                const gchar *schedule_periods);
 
+#if ENABLE_CONTAINER_SCANNING
+
+oci_image_target_t
+task_oci_image_target (task_t);
+
+int
+task_oci_image_target_in_trash (task_t);
+
+void
+set_task_oci_image_target (task_t, oci_image_target_t);
+
+#endif /* ENABLE_CONTAINER_SCANNING */
+
 void
 set_task_hosts_ordering (task_t, const char *);
 
@@ -793,7 +818,8 @@ int
 modify_task (const gchar *, const gchar *, const gchar *, const gchar *,
              const gchar *, const gchar *, const gchar *, array_t *,
              const gchar *, array_t *, const gchar *, const gchar *,
-             array_t *, const gchar *, const gchar *, gchar **, gchar **);
+             array_t *, const gchar *, const gchar *, const gchar *,
+             gchar **, gchar **);
 
 void
 init_config_file_iterator (iterator_t*, const char*, const char*);
@@ -887,21 +913,6 @@ resume_task (const char *, char **);
 int
 move_task (const char*, const char*);
 
-
-/* Access control. */
-
-int
-user_may (const char *);
-
-extern int
-user_can_everything (const char *);
-
-extern int
-user_can_super_everyone (const char *);
-
-extern int
-user_has_super (const char *, user_t);
-
 
 /* Results. */
 
@@ -2267,65 +2278,6 @@ credential_value (credential_t, const char*);
 gchar*
 credential_encrypted_value (credential_t, const char*);
 
-
-
-/* Assets. */
-
-host_t
-host_notice (const char *, const char *, const char *, const char *,
-             const char *, int, int);
-
-int
-init_resource_names_host_iterator (iterator_t *iterator, get_data_t *get);
-
-int
-asset_iterator_writable (iterator_t *);
-
-int
-asset_iterator_in_use (iterator_t *);
-
-int
-asset_host_count (const get_data_t *);
-
-int
-init_resource_names_os_iterator (iterator_t *, get_data_t *);
-
-int
-asset_os_count (const get_data_t *);
-
-int
-total_asset_count (const get_data_t *);
-
-void
-init_os_host_iterator (iterator_t *, resource_t);
-
-const char*
-os_host_iterator_severity (iterator_t *);
-
-void
-init_host_detail_iterator (iterator_t *, resource_t);
-
-const char*
-host_detail_iterator_name (iterator_t *);
-
-const char*
-host_detail_iterator_value (iterator_t *);
-
-const char*
-host_detail_iterator_source_type (iterator_t *);
-
-const char*
-host_detail_iterator_source_id (iterator_t *);
-
-int
-modify_asset (const char *, const char *);
-
-int
-delete_asset (const char *, const char *, int);
-
-int
-add_assets_from_host_in_report (report_t report, const char *host);
-
 
 /* Notes. */
 
@@ -2738,12 +2690,6 @@ get_relay_mapper_path ();
 void
 set_relay_mapper_path (const char *);
 
-int
-get_relay_migrate_sensors ();
-
-void
-set_relay_migrate_sensors (int);
-
 gboolean
 relay_supports_scanner_type (const char *, int, scanner_type_t);
 
@@ -3388,12 +3334,6 @@ manage_delete_user (GSList *, const db_conn_info_t *, const gchar *,
 int
 manage_get_users (GSList *, const db_conn_info_t *, const gchar *, int);
 
-int
-report_host_noticeable (report_t, const gchar *);
-
-gchar*
-host_routes_xml (host_t);
-
 int
 manage_set_password (GSList *, const db_conn_info_t *, const gchar *,
                      const gchar *);
@@ -3835,7 +3775,7 @@ set_vt_verification_collation (const char *);
 #if OPENVASD
 
 /* openvasd Connection */
-openvasd_connector_t
+http_scanner_connector_t
 openvasd_scanner_connect (scanner_t, const char *);
 #endif
 
