@@ -30,9 +30,9 @@
  *
  * @param[in] count Number of agent entries to allocate space for.
  *
- * @return A newly allocated agent_data_list_t on success, or NULL on memory allocation failure.
+ * @return A newly allocated agent_data_list_t on success, or NULL on memory
+ * allocation failure.
  */
-
 static agent_data_list_t
 agent_data_list_new (int count)
 {
@@ -44,6 +44,93 @@ agent_data_list_new (int count)
   return list;
 }
 
+/**
+ * @brief Deep-copy a GPtrArray of char*.
+ *
+ * @param[in] src  Source pointer array to duplicate (may be NULL).
+ *
+ * @return A newly allocated #GPtrArray on success; NULL if @p src is NULL
+ *         or if an allocation fails.
+ */
+static GPtrArray *
+dup_str_ptr_array (const GPtrArray *src)
+{
+  if (!src)
+    return NULL;
+
+  GPtrArray *dst = g_ptr_array_sized_new (src->len);
+  if (!dst)
+    return NULL;
+
+  g_ptr_array_set_free_func (dst, g_free);
+
+  for (guint i = 0; i < src->len; ++i)
+    {
+      const char *s = g_ptr_array_index ((GPtrArray *) src, i);
+      char *copy = s ? g_strdup (s) : NULL;
+
+      if (s && !copy)
+        {
+          g_ptr_array_free (dst, TRUE);
+          return NULL;
+        }
+
+      g_ptr_array_add (dst, copy);
+    }
+
+  return dst;
+}
+
+/**
+ * @brief Deep-copy a scan agent configuration structure.
+ *
+ * @param[in] src  Source configuration to copy. May be NULL.
+ *
+ * @return A newly allocated #agent_controller_scan_agent_config_t on success;
+ *         NULL if @p src is NULL or if any allocation fails. On failure, any
+ *         partially allocated memory is released.
+ */
+static agent_controller_scan_agent_config_t
+copy_agent_controller_scan_agent_config (
+  agent_controller_scan_agent_config_t src)
+{
+  if (!src)
+    return NULL;
+
+  agent_controller_scan_agent_config_t dst =
+    agent_controller_scan_agent_config_new ();
+
+  /* Plain struct copies */
+  dst->agent_control.retry.attempts = src->agent_control.retry.attempts;
+  dst->agent_control.retry.delay_in_seconds =
+    src->agent_control.retry.delay_in_seconds;
+  dst->agent_control.retry.max_jitter_in_seconds =
+    src->agent_control.retry.max_jitter_in_seconds;
+
+  dst->agent_script_executor.bulk_size = src->agent_script_executor.bulk_size;
+  dst->agent_script_executor.bulk_throttle_time_in_ms =
+    src->agent_script_executor.bulk_throttle_time_in_ms;
+  dst->agent_script_executor.indexer_dir_depth =
+    src->agent_script_executor.indexer_dir_depth;
+
+  dst->heartbeat.interval_in_seconds = src->heartbeat.interval_in_seconds;
+  dst->heartbeat.miss_until_inactive = src->heartbeat.miss_until_inactive;
+
+  /* Deep copy of GPtrArray<char*> */
+  dst->agent_script_executor.scheduler_cron_time =
+    dup_str_ptr_array (src->agent_script_executor.scheduler_cron_time);
+
+  if (src->agent_script_executor.scheduler_cron_time
+      && !dst->agent_script_executor.scheduler_cron_time)
+    {
+      /* allocation failed – clean up partial dst */
+      agent_controller_scan_agent_config_free (dst);
+      return NULL;
+    }
+
+  return dst;
+}
+
 /**
  * @brief Populate GVMD agent data list from agent controller list.
  *
@@ -52,14 +139,16 @@ agent_data_list_new (int count)
  *
  * @param[in]  list     List of agents from the agent controller.
  * @param[in]  scanner  Scanner ID associated with these agents.
- * @param[out] out_list Pre-allocated agent_data_list_t with `count` matching `list->count`.
+ * @param[out] out_list Pre-allocated agent_data_list_t with `count` matching
+ * `list->count`.
  *
- * @return AGENT_RESPONSE_SUCCESS on success, or an appropriate AGENT_RESPONSE_* error code.
+ * @return AGENT_RESPONSE_SUCCESS on success, or an appropriate AGENT_RESPONSE_*
+ * error code.
  */
 static agent_response_t
-convert_agent_control_list_to_agent_data_list (agent_controller_agent_list_t list,
-                                               scanner_t scanner,
-                                               agent_data_list_t out_list)
+convert_agent_control_list_to_agent_data_list (
+  agent_controller_agent_list_t list, scanner_t scanner,
+  agent_data_list_t out_list)
 {
   if (!list || list->count == 0 || !out_list)
     return AGENT_RESPONSE_INVALID_ARGUMENT;
@@ -87,15 +176,14 @@ convert_agent_control_list_to_agent_data_list (agent_controller_agent_list_t lis
       dest->agent_id = g_strdup (src->agent_id);
       dest->hostname = g_strdup (src->hostname);
       dest->authorized = src->authorized;
-      dest->min_interval = src->min_interval;
-      dest->heartbeat_interval = src->heartbeat_interval;
       dest->connection_status = g_strdup (src->connection_status);
       dest->last_update_agent_control = src->last_update;
-
-      if (src->schedule_config && src->schedule_config->schedule)
-        dest->schedule = g_strdup (src->schedule_config->schedule);
-      else
-        dest->schedule = g_strdup ("");
+      dest->config = copy_agent_controller_scan_agent_config (src->config);
+      dest->updater_version = g_strdup (src->updater_version);
+      dest->agent_version = g_strdup (src->agent_version);
+      dest->operating_system = g_strdup (src->operating_system);
+      dest->architecture = g_strdup (src->architecture);
+      dest->update_to_latest = src->update_to_latest;
 
       dest->scanner = scanner;
 
@@ -104,15 +192,18 @@ convert_agent_control_list_to_agent_data_list (agent_controller_agent_list_t lis
         {
           dest->ip_addresses = agent_ip_data_list_new (src->ip_address_count);
           dest->ip_addresses->count = src->ip_address_count;
-          dest->ip_addresses->items = g_malloc0 (sizeof (agent_ip_data_t) * src->ip_address_count);
+          dest->ip_addresses->items =
+            g_malloc0 (sizeof (agent_ip_data_t) * src->ip_address_count);
 
           for (int j = 0; j < src->ip_address_count; ++j)
             {
               if (!src->ip_addresses[j])
                 continue;
 
-              dest->ip_addresses->items[j] = g_malloc0 (sizeof (struct agent_ip_data));
-              dest->ip_addresses->items[j]->ip_address = g_strdup (src->ip_addresses[j]);
+              dest->ip_addresses->items[j] =
+                g_malloc0 (sizeof (struct agent_ip_data));
+              dest->ip_addresses->items[j]->ip_address =
+                g_strdup (src->ip_addresses[j]);
             }
         }
       else
@@ -136,8 +227,8 @@ convert_agent_control_list_to_agent_data_list (agent_controller_agent_list_t lis
  * Transforms internal GVMD agent records into a format understood
  * by the agent controller for update or deletion operations.
  *
- * The caller is responsible for freeing the populated `agent_controller_agent_list_t`
- * using the appropriate cleanup function.
+ * The caller is responsible for freeing the populated
+ * `agent_controller_agent_list_t` using the appropriate cleanup function.
  *
  * @param[in]  list      Source list of GVMD agent_data_t entries.
  * @param[out] out_list  Target agent controller list to populate.
@@ -145,8 +236,8 @@ convert_agent_control_list_to_agent_data_list (agent_controller_agent_list_t lis
  * @return AGENT_RESPONSE_SUCCESS on success, otherwise an error code on failure
  */
 static agent_response_t
-convert_agent_data_list_to_agent_control_list (agent_data_list_t list,
-                                               agent_controller_agent_list_t out_list)
+convert_agent_data_list_to_agent_control_list (
+  agent_data_list_t list, agent_controller_agent_list_t out_list)
 {
   if (!list || list->count == 0)
     return AGENT_RESPONSE_INVALID_ARGUMENT;
@@ -159,27 +250,27 @@ convert_agent_data_list_to_agent_control_list (agent_data_list_t list,
       dest->agent_id = g_strdup (src->agent_id);
       dest->hostname = g_strdup (src->hostname);
       dest->authorized = src->authorized;
-      dest->min_interval = src->min_interval;
-      dest->heartbeat_interval = src->heartbeat_interval;
       dest->connection_status = g_strdup (src->connection_status);
       dest->last_update = src->last_update_agent_control;
-
-      // Schedule config
-      if (src->schedule && strlen (src->schedule) > 0)
-        {
-          dest->schedule_config = agent_controller_config_schedule_new ();
-          dest->schedule_config->schedule = g_strdup (src->schedule);
-        }
+      dest->last_updater_heartbeat = src->last_updater_heartbeat;
+      dest->config = copy_agent_controller_scan_agent_config (src->config);
+      dest->updater_version = g_strdup (src->updater_version);
+      dest->agent_version = g_strdup (src->agent_version);
+      dest->operating_system = g_strdup (src->operating_system);
+      dest->architecture = g_strdup (src->architecture);
+      dest->last_update = src->update_to_latest;
 
       // IP addresses
       if (src->ip_addresses && src->ip_addresses->count > 0)
         {
           dest->ip_address_count = src->ip_addresses->count;
-          dest->ip_addresses = g_malloc0 (sizeof (char *) * dest->ip_address_count);
+          dest->ip_addresses =
+            g_malloc0 (sizeof (char *) * dest->ip_address_count);
 
           for (int j = 0; j < dest->ip_address_count; ++j)
             {
-              dest->ip_addresses[j] = g_strdup (src->ip_addresses->items[j]->ip_address);
+              dest->ip_addresses[j] =
+                g_strdup (src->ip_addresses->items[j]->ip_address);
             }
         }
 
@@ -198,12 +289,13 @@ convert_agent_data_list_to_agent_control_list (agent_data_list_t list,
  * @param[in]  agent_uuids  List of agent UUIDs to retrieve.
  * @param[out] out_list     Output list for agent controller formatted agents.
  *
- * @return AGENT_RESPONSE_SUCCESS on success, or an appropriate error code on failure.
+ * @return AGENT_RESPONSE_SUCCESS on success, or an appropriate error code on
+ * failure.
  */
 static agent_response_t
 get_agent_controller_agents_from_uuids (scanner_t scanner,
-                                       agent_uuid_list_t agent_uuids,
-                                       agent_controller_agent_list_t out_list)
+                                        agent_uuid_list_t agent_uuids,
+                                        agent_controller_agent_list_t out_list)
 {
   if (!scanner)
     {
@@ -224,9 +316,8 @@ get_agent_controller_agents_from_uuids (scanner_t scanner,
     }
 
   agent_data_list_t agent_data_list = agent_data_list_new (agent_uuids->count);
-  agent_response_t get_agent_result = get_agents_by_scanner_and_uuids (scanner,
-                                                                       agent_uuids,
-                                                                       agent_data_list);
+  agent_response_t get_agent_result =
+    get_agents_by_scanner_and_uuids (scanner, agent_uuids, agent_data_list);
   if (get_agent_result != 0)
     {
       agent_data_list_free (agent_data_list);
@@ -235,7 +326,8 @@ get_agent_controller_agents_from_uuids (scanner_t scanner,
       return get_agent_result;
     }
 
-   int convert_result = convert_agent_data_list_to_agent_control_list (agent_data_list, out_list);
+  int convert_result =
+    convert_agent_data_list_to_agent_control_list (agent_data_list, out_list);
 
   if (convert_result != AGENT_RESPONSE_SUCCESS)
     {
@@ -249,7 +341,8 @@ get_agent_controller_agents_from_uuids (scanner_t scanner,
 }
 
 /**
- * @brief Maps the return value of get_scanner_from_agent_uuid() to agent_response_t.
+ * @brief Maps the return value of get_scanner_from_agent_uuid() to
+ * agent_response_t.
  *
  * @param[in] result Return code from get_scanner_from_agent_uuid().
  *
@@ -275,81 +368,6 @@ map_get_scanner_result_to_agent_response (int result)
     }
 }
 
-/**
- * @brief Initialize a new GVMD agent connector from a scanner.
- *
- * Builds and configures a connection to the agent controller using
- * scanner information.
- *
- * @param[in] scanner  Scanner ID used to resolve connection info.
- * @return Allocated gvmd_agent_connector_t or NULL on failure.
- */
-gvmd_agent_connector_t
-gvmd_agent_connector_new_from_scanner (scanner_t scanner)
-{
-  assert (scanner);
-
-  gboolean has_relay = scanner_has_relay (scanner);
-  char *host = scanner_host (scanner, has_relay);
-  int port = scanner_port (scanner, has_relay);
-  char *ca_cert = scanner_ca_pub (scanner);
-  char *cert = scanner_key_pub (scanner);
-  char *key = scanner_key_priv (scanner);
-
-  if (!host || port <= 0)
-    {
-      g_warning ("%s: Invalid scanner host or port", __func__);
-      g_free (host);
-      g_free (ca_cert);
-      g_free (cert);
-      g_free (key);
-      return NULL;
-    }
-
-  const char *protocol = "https";
-  if (!ca_cert || !cert)
-    {
-      g_debug ("%s: Falling back to HTTP due to missing CA or cert", __func__);
-      protocol = "http";
-    }
-
-  gvmd_agent_connector_t conn = g_malloc0 (sizeof (struct gvmd_agent_connector));
-  conn->base = agent_controller_connector_new ();
-
-  agent_controller_connector_builder (conn->base, AGENT_CONTROLLER_HOST, host);
-  agent_controller_connector_builder (conn->base, AGENT_CONTROLLER_PORT, &port);
-  agent_controller_connector_builder (conn->base, AGENT_CONTROLLER_PROTOCOL, protocol);
-
-  if (ca_cert)
-    agent_controller_connector_builder (conn->base, AGENT_CONTROLLER_CA_CERT, ca_cert);
-  if (cert)
-    agent_controller_connector_builder (conn->base, AGENT_CONTROLLER_CERT, cert);
-  if (key)
-    agent_controller_connector_builder (conn->base, AGENT_CONTROLLER_KEY, key);
-
-  conn->scanner_id = scanner;
-
-  g_free (host);
-  g_free (ca_cert);
-  g_free (cert);
-  g_free (key);
-
-  return conn;
-}
-
-/**
- * @brief Free a GVMD agent connector.
- *
- * @param[in] conn GVMD agent connector to free.
- */
-void
-gvmd_agent_connector_free (gvmd_agent_connector_t conn)
-{
-  if (!conn) return;
-  agent_controller_connector_free (conn->base);
-  g_free (conn);
-}
-
 /**
  * @brief Free an agent_ip_data_list_t and its contents.
  *
@@ -368,24 +386,25 @@ agent_ip_data_list_free (agent_ip_data_list_t ip_list)
           if (ip_list->items[i])
             {
               if (ip_list->items[i]->ip_address)
-                g_free(ip_list->items[i]->ip_address);
+                g_free (ip_list->items[i]->ip_address);
 
-              g_free(ip_list->items[i]);
+              g_free (ip_list->items[i]);
               ip_list->items[i] = NULL;
             }
         }
-      g_free(ip_list->items);
+      g_free (ip_list->items);
       ip_list->items = NULL;
     }
 
-  g_free(ip_list);
+  g_free (ip_list);
 }
 
 /**
  * @brief Allocate and initialize an agent_ip_data_list_t structure.
  *
  * @param[in] count Number of IP address items to allocate.
- * @return A newly allocated agent_ip_data_list_t, or NULL on allocation failure.
+ * @return A newly allocated agent_ip_data_list_t, or NULL on allocation
+ * failure.
  */
 agent_ip_data_list_t
 agent_ip_data_list_new (int count)
@@ -441,8 +460,20 @@ agent_data_free (agent_data_t data)
   if (data->connection_status)
     g_free (data->connection_status);
 
-  if (data->schedule)
-    g_free (data->schedule);
+  if (data->config)
+    agent_controller_scan_agent_config_free (data->config);
+
+  if (data->updater_version)
+    g_free (data->updater_version);
+
+  if (data->agent_version)
+    g_free (data->agent_version);
+
+  if (data->operating_system)
+    g_free (data->operating_system);
+
+  if (data->architecture)
+    g_free (data->architecture);
 
   if (data->comment)
     g_free (data->comment);
@@ -481,7 +512,8 @@ agent_data_list_free (agent_data_list_t agents)
  * Gets all agent information from the agent controller
  * and saves it into GVMD's internal database.
  *
- * @param[in] connector An initialized agent controller connector with scanner ID.
+ * @param[in] connector An initialized agent controller connector with scanner
+ * ID.
  *
  * @return AGENT_RESPONSE_SUCCESS on success,
  *         or a specific AGENT_RESPONSE_* error code on failure.
@@ -504,13 +536,13 @@ sync_agents_from_agent_controller (gvmd_agent_connector_t connector)
       return AGENT_RESPONSE_SUCCESS;
     }
 
-  agent_data_list_t agent_data_list = agent_data_list_new (agent_controller_agents->count);
-  agent_response_t convert_result = convert_agent_control_list_to_agent_data_list (
-                                                      agent_controller_agents,
-                                                      connector->scanner_id,
-                                                      agent_data_list);
+  agent_data_list_t agent_data_list =
+    agent_data_list_new (agent_controller_agents->count);
+  agent_response_t convert_result =
+    convert_agent_control_list_to_agent_data_list (
+      agent_controller_agents, connector->scanner_id, agent_data_list);
 
-  if (convert_result!= AGENT_RESPONSE_SUCCESS)
+  if (convert_result != AGENT_RESPONSE_SUCCESS)
     {
       agent_data_list_free (agent_data_list);
       agent_controller_agent_list_free (agent_controller_agents);
@@ -542,15 +574,13 @@ sync_agents_from_agent_controller (gvmd_agent_connector_t connector)
  * @param[in]  uuid_list  List of agent UUIDs to look up.
  * @param[out] out_list   Output list to populate with matching agents.
  *
-* @return AGENT_RESPONSE_SUCCESS on success,
+ * @return AGENT_RESPONSE_SUCCESS on success,
  *         or a specific AGENT_RESPONSE_* error code on failure.
  */
 agent_response_t
-get_agents_by_scanner_and_uuids (scanner_t scanner,
-                                 agent_uuid_list_t uuid_list,
+get_agents_by_scanner_and_uuids (scanner_t scanner, agent_uuid_list_t uuid_list,
                                  agent_data_list_t out_list)
 {
-
   if (!out_list || !uuid_list || out_list->count == 0 || uuid_list->count == 0)
     return AGENT_RESPONSE_INVALID_ARGUMENT;
 
@@ -565,25 +595,37 @@ get_agents_by_scanner_and_uuids (scanner_t scanner,
       if (agent_iterator_scanner (&iterator) != scanner)
         {
           cleanup_iterator (&iterator);
-          return AGENT_RESPONSE_AGENT_SCANNER_MISMATCH;  // Mismatch found, early exit
+          return AGENT_RESPONSE_AGENT_SCANNER_MISMATCH;
         }
 
       agent_data_t agent = g_malloc0 (sizeof (struct agent_data));
       if (!agent)
         continue;
 
+      /* config conversion */
+      const gchar *cfg_str = g_strdup (agent_iterator_config (&iterator));
+      agent_controller_scan_agent_config_t config =
+        agent_controller_parse_scan_agent_config_string (cfg_str);
+
       agent->row_id = iterator_int64 (&iterator, 0);
       agent->agent_id = g_strdup (agent_iterator_agent_id (&iterator));
       agent->hostname = g_strdup (agent_iterator_hostname (&iterator));
       agent->authorized = agent_iterator_authorized (&iterator);
-      agent->min_interval = agent_iterator_min_interval (&iterator);
-      agent->heartbeat_interval = agent_iterator_heartbeat_interval (&iterator);
-      agent->connection_status = g_strdup (agent_iterator_connection_status (&iterator));
+      agent->connection_status =
+        g_strdup (agent_iterator_connection_status (&iterator));
       agent->last_update_agent_control = agent_iterator_last_update (&iterator);
-      agent->schedule = g_strdup (agent_iterator_schedule (&iterator));
+      agent->config = config;
       agent->comment = g_strdup (get_iterator_comment (&iterator));
       agent->creation_time = get_iterator_creation_time (&iterator);
       agent->modification_time = get_iterator_modification_time (&iterator);
+      agent->updater_version =
+        g_strdup (agent_iterator_updater_version (&iterator));
+      agent->agent_version =
+        g_strdup (agent_iterator_agent_version (&iterator));
+      agent->operating_system =
+        g_strdup (agent_iterator_operating_system (&iterator));
+      agent->architecture = g_strdup (agent_iterator_architecture (&iterator));
+      agent->update_to_latest = agent_iterator_update_to_latest (&iterator);
       agent->scanner = scanner;
       agent->owner = get_iterator_owner (&iterator);
       agent->uuid = g_strdup (get_iterator_uuid (&iterator));
@@ -608,8 +650,8 @@ get_agents_by_scanner_and_uuids (scanner_t scanner,
  * Sends update instructions for the selected agents and re-synchronizes
  * their state from the agent controller.
  *
-* @param[in]  agent_uuids   List of agent UUIDs to be modified.
- * @param[in]  agent_update  Update parameters to apply (e.g., authorize/revoke).
+ * @param[in]  agent_uuids   List of agent UUIDs to be modified.
+ * @param[in]  agent_update  Update parameters to apply (e.g. authorize/revoke).
  * @param[in]  comment       Optional comment string to apply to agents in GVMD.
  *
  * @return AGENT_RESPONSE_SUCCESS on success,
@@ -618,7 +660,8 @@ get_agents_by_scanner_and_uuids (scanner_t scanner,
 agent_response_t
 modify_and_resync_agents (agent_uuid_list_t agent_uuids,
                           agent_controller_agent_update_t agent_update,
-                          const gchar *comment)
+                          const gchar *comment,
+                          GPtrArray **errors)
 {
   scanner_t scanner = 0;
   agent_controller_agent_list_t agent_control_list = NULL;
@@ -630,15 +673,14 @@ modify_and_resync_agents (agent_uuid_list_t agent_uuids,
     }
 
   int ret = get_scanner_from_agent_uuid (agent_uuids->agent_uuids[0], &scanner);
-  agent_response_t map_response = map_get_scanner_result_to_agent_response (ret);
+  agent_response_t map_response =
+    map_get_scanner_result_to_agent_response (ret);
   if (map_response != AGENT_RESPONSE_SUCCESS)
     return map_response;
 
   agent_control_list = agent_controller_agent_list_new (agent_uuids->count);
   agent_response_t get_response = get_agent_controller_agents_from_uuids (
-                                       scanner,
-                                       agent_uuids,
-                                       agent_control_list);
+    scanner, agent_uuids, agent_control_list);
   if (get_response != AGENT_RESPONSE_SUCCESS)
     {
       agent_controller_agent_list_free (agent_control_list);
@@ -655,9 +697,16 @@ modify_and_resync_agents (agent_uuid_list_t agent_uuids,
     }
 
   int update_result = agent_controller_update_agents (
-                        connector->base,
-                        agent_control_list,
-                        agent_update);
+  connector->base, agent_control_list, agent_update, errors);
+
+  if (update_result < 0 && errors && *errors && (*errors)->len > 0)
+    {
+      g_warning ("%s: agent_controller_update_agents rejected", __func__);
+      agent_controller_agent_list_free (agent_control_list);
+      gvmd_agent_connector_free (connector);
+      manage_option_cleanup ();
+      return AGENT_RESPONSE_CONTROLLER_UPDATE_REJECTED;
+    }
 
   if (update_result < 0)
     {
@@ -668,8 +717,8 @@ modify_and_resync_agents (agent_uuid_list_t agent_uuids,
       return AGENT_RESPONSE_CONTROLLER_UPDATE_FAILED;
     }
 
- if (comment)
-   update_agents_comment (agent_uuids, comment);
+  if (comment)
+    update_agents_comment (agent_uuids, comment);
 
   agent_response_t result = sync_agents_from_agent_controller (connector);
   if (result != AGENT_RESPONSE_SUCCESS)
@@ -713,15 +762,14 @@ delete_and_resync_agents (agent_uuid_list_t agent_uuids)
     }
 
   int ret = get_scanner_from_agent_uuid (agent_uuids->agent_uuids[0], &scanner);
-  agent_response_t map_response = map_get_scanner_result_to_agent_response (ret);
+  agent_response_t map_response =
+    map_get_scanner_result_to_agent_response (ret);
   if (map_response != AGENT_RESPONSE_SUCCESS)
     return map_response;
 
   agent_control_list = agent_controller_agent_list_new (agent_uuids->count);
   agent_response_t get_result = get_agent_controller_agents_from_uuids (
-                                     scanner,
-                                     agent_uuids,
-                                     agent_control_list);
+    scanner, agent_uuids, agent_control_list);
   if (get_result != AGENT_RESPONSE_SUCCESS)
     {
       agent_controller_agent_list_free (agent_control_list);
@@ -744,9 +792,8 @@ delete_and_resync_agents (agent_uuid_list_t agent_uuids)
       return AGENT_RESPONSE_CONNECTOR_CREATION_FAILED;
     }
 
-  int update_result = agent_controller_delete_agents (
-                        connector->base,
-                        agent_control_list);
+  int update_result =
+    agent_controller_delete_agents (connector->base, agent_control_list);
 
   if (update_result < 0)
     {
