@@ -103,6 +103,8 @@
  */
 #define SCANNER_UUID_OPENVASD_DEFAULT "8154d8e3-30ee-4959-9151-1863c89a8e62"
 
+#define SCANNER_UUID_CONTAINER_IMAGE_DEFAULT "1facb485-10e8-4520-9110-66f929d9ac2e"
+
 /**
  * @brief UUID of 'CVE' scanner.
  */
@@ -196,24 +198,6 @@ host_nthlast_report_host (const char *, report_host_t *, int);
 report_host_t
 host_iterator_report_host (iterator_t *);
 
-char *
-report_host_ip (const char *);
-
-gchar *
-report_host_hostname (report_host_t);
-
-gchar *
-report_host_best_os_cpe (report_host_t);
-
-gchar *
-report_host_best_os_txt (report_host_t);
-
-int
-report_host_dead (report_host_t);
-
-int
-report_host_result_count (report_host_t);
-
 void
 init_report_host_details_iterator (iterator_t *, report_host_t);
 
@@ -407,6 +391,11 @@ int
 count (const char *, const get_data_t *, column_t *, column_t *, const char **,
        int, const char *, const char *, int);
 
+int
+count2 (const char *, const get_data_t *, column_t *, column_t *, column_t *,
+        column_t *, const char **, int, const char *, const char *,
+        const char *, int);
+
 int
 init_get_iterator (iterator_t*, const char *, const get_data_t *, column_t *,
                    column_t *, const char **, int, const char *, const char *,
@@ -571,20 +560,6 @@ check_host_detail_exists (report_t, const char *, const char *, const char *,
                           const char *, const char *, const char *, char **,
                           GHashTable *);
 
-// FIX moved here for now, until more code goes to manage*_assets.c
-/**
- * @brief Host identifier type.
- */
-typedef struct
-{
-  gchar *ip;                ///< IP of host.
-  gchar *name;              ///< Name of identifier, like "hostname".
-  gchar *value;             ///< Value of identifier.
-  gchar *source_type;       ///< Type of identifier source, like "Report Host".
-  gchar *source_id;         ///< ID of source.
-  gchar *source_data;       ///< Extra data for source.
-} identifier_t;
-
 #if OPENVASD
 void
 parse_openvasd_report (task_t, report_t, GSList *, time_t, time_t);
