@@ -17,6 +17,7 @@
 #if ENABLE_AGENTS
 
 #include "manage_sql_agents.h"
+
 #include "manage_sql_copy.h"
 
 #include <util/uuidutils.h>
@@ -36,8 +37,7 @@ static void
 delete_existing_agent_ips (const gchar *agent_id)
 {
   gchar *insert_agent_id = sql_insert (agent_id);
-   sql ("DELETE FROM agent_ip_addresses WHERE agent_id = %s;",
-                  insert_agent_id);
+  sql ("DELETE FROM agent_ip_addresses WHERE agent_id = %s;", insert_agent_id);
   g_free (insert_agent_id);
 }
 
@@ -58,8 +58,8 @@ agent_column_exists (const gchar *column_name, const gchar *value)
     }
 
   gchar *insert_value = sql_insert (value);
-  gchar *query = g_strdup_printf (
-    "SELECT COUNT(*) FROM agents WHERE %s = %s;", column_name, insert_value);
+  gchar *query = g_strdup_printf ("SELECT COUNT(*) FROM agents WHERE %s = %s;",
+                                  column_name, insert_value);
 
   int result = sql_int (query);
 
@@ -80,31 +80,51 @@ agent_column_exists (const gchar *column_name, const gchar *value)
 static void
 update_existing_agent (agent_data_t agent)
 {
-   gchar *insert_hostname = sql_insert (agent->hostname);
-   gchar *insert_connection_status = sql_insert (agent->connection_status);
-   gchar *insert_schedule = sql_insert (agent->schedule);
-   gchar *insert_agent_id = sql_insert (agent->agent_id);
+  gchar *config_string =
+    agent_controller_convert_scan_agent_config_string (agent->config);
+  if (!config_string)
+    config_string = g_strdup ("");
 
-   sql ("UPDATE agents SET hostname = %s, authorized = %d, min_interval = %d,"
-        " heartbeat_interval = %d, connection_status = %s, last_update = %ld,"
-        " schedule = %s, owner = %u, modification_time = %ld, scanner = %llu "
-        " WHERE agent_id = %s;",
-        insert_hostname,
-        agent->authorized,
-        agent->min_interval,
-        agent->heartbeat_interval,
-        insert_connection_status,
-        agent->last_update_agent_control,
-        insert_schedule,
-        agent->owner,
-        agent->modification_time,
-        agent->scanner,
-        insert_agent_id);
+  gchar *insert_hostname = sql_insert (agent->hostname);
+  gchar *insert_connection_status = sql_insert (agent->connection_status);
+  gchar *insert_config = sql_insert (config_string);
+  gchar *insert_agent_id = sql_insert (agent->agent_id);
+  gchar *insert_updater_version = sql_insert (agent->updater_version);
+  gchar *insert_agent_version = sql_insert (agent->agent_version);
+  gchar *insert_operating_system = sql_insert (agent->operating_system);
+  gchar *insert_architecture = sql_insert (agent->architecture);
+
+  sql ("UPDATE agents SET "
+       " hostname = %s,"
+       " authorized = %d,"
+       " connection_status = %s,"
+       " last_update = %ld,"
+       " last_updater_heartbeat = %ld,"
+       " config = %s,"
+       " owner = %u,"
+       " modification_time = %ld,"
+       " scanner = %llu,"
+       " updater_version = %s,"
+       " agent_version = %s,"
+       " operating_system = %s,"
+       " architecture = %s,"
+       " update_to_latest = %d"
+       " WHERE agent_id = %s;",
+       insert_hostname, agent->authorized, insert_connection_status,
+       agent->last_update_agent_control, agent->last_updater_heartbeat,
+       insert_config, agent->owner, agent->modification_time, agent->scanner,
+       insert_updater_version, insert_agent_version, insert_operating_system,
+       insert_architecture, agent->update_to_latest ? 1 : 0, insert_agent_id);
 
   g_free (insert_hostname);
   g_free (insert_connection_status);
-  g_free (insert_schedule);
+  g_free (insert_config);
   g_free (insert_agent_id);
+  g_free (insert_updater_version);
+  g_free (insert_agent_version);
+  g_free (insert_operating_system);
+  g_free (insert_architecture);
+  g_free (config_string);
 }
 
 /**
@@ -122,35 +142,44 @@ append_agent_row_to_buffer (db_copy_buffer_t *buffer, agent_data_t agent)
       if (agent->uuid == NULL)
         return;
     }
-   gchar *escaped_hostname =  sql_copy_escape (agent->hostname);
-   gchar *escaped_connection_status =  sql_copy_escape (agent->connection_status);
-   gchar *escaped_schedule =  sql_copy_escape (agent->schedule);
-   gchar *escaped_comment =  sql_copy_escape ("");
+
+  gchar *config_string =
+    agent_controller_convert_scan_agent_config_string (agent->config);
+  if (!config_string)
+    config_string = g_strdup ("");
+
+  gchar *escaped_hostname = sql_copy_escape (agent->hostname);
+  gchar *escaped_connection_status = sql_copy_escape (agent->connection_status);
+  gchar *escaped_config = sql_copy_escape (config_string);
+  gchar *escaped_comment = sql_copy_escape ("");
+
+  gchar *escaped_updater_version = sql_copy_escape (agent->updater_version);
+  gchar *escaped_agent_version = sql_copy_escape (agent->agent_version);
+  gchar *escaped_operating_system = sql_copy_escape (agent->operating_system);
+  gchar *escaped_architecture = sql_copy_escape (agent->architecture);
 
   db_copy_buffer_append_printf (
     buffer,
-    "%s\t%s\t%s\t%s\t%d\t%d\t%d\t%s\t%ld\t%s\t%u\t%s\t%ld\t%ld\t%llu\n",
-    agent->uuid,
-    agent->name,
-    agent->agent_id,
-    escaped_hostname,
-    agent->authorized,
-    agent->min_interval,
-    agent->heartbeat_interval,
-    escaped_connection_status,
-    agent->last_update_agent_control,
-    escaped_schedule,
-    agent->owner,
-    escaped_comment,
-    time (NULL),     // creation time
-    agent->modification_time,
-    agent->scanner
-  );
+    "%s\t%s\t%s\t%llu\t%s\t%d\t%s\t%ld\t%ld\t%s\t%u\t%s\t%ld\t%ld\t%s\t%s\t%"
+    "s\t%s\t%d\n",
+    agent->uuid, agent->name, agent->agent_id, agent->scanner, escaped_hostname,
+    agent->authorized, escaped_connection_status,
+    agent->last_update_agent_control, agent->last_updater_heartbeat,
+    escaped_config, agent->owner, escaped_comment,
+    time (NULL), // creation_time
+    agent->modification_time, escaped_updater_version, escaped_agent_version,
+    escaped_operating_system, escaped_architecture,
+    agent->update_to_latest ? 1 : 0);
 
   g_free (escaped_hostname);
   g_free (escaped_connection_status);
-  g_free (escaped_schedule);
+  g_free (escaped_config);
   g_free (escaped_comment);
+  g_free (escaped_updater_version);
+  g_free (escaped_agent_version);
+  g_free (escaped_operating_system);
+  g_free (escaped_architecture);
+  g_free (config_string);
 }
 
 /**
@@ -161,24 +190,21 @@ append_agent_row_to_buffer (db_copy_buffer_t *buffer, agent_data_t agent)
  * @param[in] ip_list  List of IP addresses to append.
  */
 static void
-append_ip_rows_to_buffer (db_copy_buffer_t *buffer,
-                          const gchar *agent_id,
+append_ip_rows_to_buffer (db_copy_buffer_t *buffer, const gchar *agent_id,
                           agent_ip_data_list_t ip_list)
 {
-  if (!ip_list) return;
+  if (!ip_list)
+    return;
 
-  gchar *escaped_agent_id =  sql_copy_escape (agent_id);
+  gchar *escaped_agent_id = sql_copy_escape (agent_id);
 
   for (int j = 0; j < ip_list->count; ++j)
     {
       agent_ip_data_t ip = ip_list->items[j];
-      gchar *escaped_ip_address =  sql_copy_escape (ip->ip_address);
+      gchar *escaped_ip_address = sql_copy_escape (ip->ip_address);
 
-      db_copy_buffer_append_printf (
-        buffer,
-        "%s\t%s\n",
-        escaped_agent_id,
-        escaped_ip_address);
+      db_copy_buffer_append_printf (buffer, "%s\t%s\n", escaped_agent_id,
+                                    escaped_ip_address);
 
       g_free (escaped_ip_address);
     }
@@ -202,7 +228,6 @@ append_ip_rows_to_buffer (db_copy_buffer_t *buffer,
 int
 get_scanner_from_agent_uuid (const gchar *agent_uuid, scanner_t *scanner)
 {
-
   if (!agent_uuid)
     {
       g_warning ("%s: Agent UUID is required but missing", __func__);
@@ -213,7 +238,8 @@ get_scanner_from_agent_uuid (const gchar *agent_uuid, scanner_t *scanner)
   int exists = agent_column_exists ("uuid", agent_uuid);
   if (exists == -1)
     {
-      g_warning ("%s: Failed to check if agent UUID '%s' exists (DB error)", __func__, agent_uuid);
+      g_warning ("%s: Failed to check if agent UUID '%s' exists (DB error)",
+                 __func__, agent_uuid);
       manage_option_cleanup ();
       return -2;
     }
@@ -225,12 +251,14 @@ get_scanner_from_agent_uuid (const gchar *agent_uuid, scanner_t *scanner)
     }
 
   gchar *insert_agent_uuid = sql_insert (agent_uuid);
-  *scanner = sql_int ("SELECT scanner FROM agents WHERE uuid = %s;", insert_agent_uuid);
+  *scanner =
+    sql_int ("SELECT scanner FROM agents WHERE uuid = %s;", insert_agent_uuid);
   g_free (insert_agent_uuid);
 
   if (*scanner <= 0)
     {
-      g_warning ("%s: Failed to find scanner for agent UUID %s", __func__, agent_uuid);
+      g_warning ("%s: Failed to find scanner for agent UUID %s", __func__,
+                 agent_uuid);
       manage_option_cleanup ();
       return -4;
     }
@@ -253,24 +281,36 @@ sync_agents_from_data_list (agent_data_list_t agent_list)
   if (!agent_list || agent_list->count == 0)
     return 0;
 
-  db_copy_buffer_t agent_buffer = { 0 };
-  db_copy_buffer_t ip_buffer = { 0 };
+  db_copy_buffer_t agent_buffer = {0};
+  db_copy_buffer_t ip_buffer = {0};
   int status = 0;
 
-  db_copy_buffer_init (
-    &agent_buffer,
-    64 * 1024,
-    "COPY agents (uuid, name, agent_id, hostname, authorized, min_interval, heartbeat_interval,"
-    " connection_status, last_update, schedule, owner, comment, creation_time,"
-    " modification_time, scanner) FROM STDIN;"
-  );
-
+  db_copy_buffer_init (&agent_buffer, 64 * 1024,
+                       "COPY agents ("
+                       " uuid,"
+                       " name,"
+                       " agent_id,"
+                       " scanner,"
+                       " hostname,"
+                       " authorized,"
+                       " connection_status,"
+                       " last_update,"
+                       " last_updater_heartbeat,"
+                       " config,"
+                       " owner,"
+                       " comment,"
+                       " creation_time,"
+                       " modification_time,"
+                       " updater_version,"
+                       " agent_version,"
+                       " operating_system,"
+                       " architecture,"
+                       " update_to_latest"
+                       ") FROM STDIN;");
 
   db_copy_buffer_init (
-    &ip_buffer,
-    32 * 1024,
-    "COPY agent_ip_addresses (agent_id, ip_address) FROM STDIN;"
-  );
+    &ip_buffer, 32 * 1024,
+    "COPY agent_ip_addresses (agent_id, ip_address) FROM STDIN;");
 
   sql_begin_immediate ();
 
@@ -282,15 +322,16 @@ sync_agents_from_data_list (agent_data_list_t agent_list)
 
       if (exists)
         {
-          update_existing_agent(agent);
-          delete_existing_agent_ips(agent->agent_id);
+          update_existing_agent (agent);
+          delete_existing_agent_ips (agent->agent_id);
         }
       else
         {
           append_agent_row_to_buffer (&agent_buffer, agent);
         }
 
-      append_ip_rows_to_buffer (&ip_buffer, agent->agent_id, agent->ip_addresses);
+      append_ip_rows_to_buffer (&ip_buffer, agent->agent_id,
+                                agent->ip_addresses);
     }
 
   if (db_copy_buffer_commit (&agent_buffer, TRUE))
@@ -323,7 +364,8 @@ sync_agents_from_data_list (agent_data_list_t agent_list)
  * @brief Initialize SQL-based agent iterator with filtering support.
  *
  * @param[out] iterator Pointer to the iterator to initialize.
- * @param[in]  get      Get parameters containing filtering criteria (e.g., agent ID).
+ * @param[in]  get      Get parameters containing filtering criteria (e.g.,
+ * agent ID).
  *
  * @return 0 on success, -1 on failure.
  */
@@ -345,16 +387,12 @@ init_agent_iterator (iterator_t *iterator, get_data_t *get)
       where_clause = g_strdup_printf ("agent_id = '%s'", quoted);
     }
 
-  int ret = init_get_iterator (iterator,
-                               "agent",
-                               get,
-                               columns,
-                               NULL,              // no trash columns
+  int ret = init_get_iterator (iterator, "agent", get, columns,
+                               NULL, // no trash columns
                                filter_columns,
-                               0,                 // no trashcan
-                               NULL,              // no joins
-                               where_clause,
-                               0);
+                               0,    // no trashcan
+                               NULL, // no joins
+                               where_clause, 0);
 
   g_free (where_clause);
   g_free (quoted);
@@ -363,7 +401,8 @@ init_agent_iterator (iterator_t *iterator, get_data_t *get)
 }
 
 /**
- * @brief Initialize an agent iterator for a specific scanner and list of agent UUIDs.
+ * @brief Initialize an agent iterator for a specific scanner and list of agent
+ * UUIDs.
  *
  * @param[out] iterator  Pointer to the iterator to initialize.
  * @param[in] uuid_list List of agent UUIDs to include in the iteration.
@@ -373,7 +412,7 @@ init_agent_uuid_list_iterator (iterator_t *iterator,
                                agent_uuid_list_t uuid_list)
 {
   get_data_t get;
-  memset(&get, 0, sizeof(get));
+  memset (&get, 0, sizeof (get));
   get.type = "agent";
   get.ignore_pagination = 1;
   get.ignore_max_rows_per_page = 1;
@@ -387,8 +426,7 @@ init_agent_uuid_list_iterator (iterator_t *iterator,
       for (int i = 0; i < uuid_list->count; ++i)
         {
           gchar *quoted_uuid = sql_quote (uuid_list->agent_uuids[i]);
-          g_string_append_printf (where_clause, "'%s'%s",
-                                  quoted_uuid,
+          g_string_append_printf (where_clause, "'%s'%s", quoted_uuid,
                                   (i < uuid_list->count - 1) ? ", " : "");
           g_free (quoted_uuid);
         }
@@ -396,16 +434,12 @@ init_agent_uuid_list_iterator (iterator_t *iterator,
     }
   static column_t columns[] = AGENT_ITERATOR_COLUMNS;
   static const char *filter_columns[] = AGENT_ITERATOR_FILTER_COLUMNS;
-  init_get_iterator (iterator,
-                     "agent",
-                     &get,
-                     columns,
-                     NULL,              // no trash columns
+  init_get_iterator (iterator, "agent", &get, columns,
+                     NULL, // no trash columns
                      filter_columns,
-                     0,                 // no trashcan
-                     NULL,              // no joins
-                     where_clause->str,
-                     0);
+                     0,    // no trashcan
+                     NULL, // no joins
+                     where_clause->str, 0);
 
   g_string_free (where_clause, TRUE);
 }
@@ -425,7 +459,7 @@ load_agent_ip_addresses (const char *agent_id)
   gchar *inserted_agent_id = sql_insert (agent_id);
   gchar *count_query = g_strdup_printf (
     "SELECT COUNT(*) FROM agent_ip_addresses WHERE agent_id = %s;",
-          inserted_agent_id);
+    inserted_agent_id);
   int count = sql_int (count_query);
   g_free (count_query);
 
@@ -438,9 +472,10 @@ load_agent_ip_addresses (const char *agent_id)
 
   iterator_t ip_iterator;
 
-  init_iterator (&ip_iterator,
-                 "SELECT ip_address FROM agent_ip_addresses WHERE agent_id = %s;",
-                 inserted_agent_id);
+  init_iterator (
+    &ip_iterator,
+    "SELECT ip_address FROM agent_ip_addresses WHERE agent_id = %s;",
+    inserted_agent_id);
 
   int index = 0;
   while (next (&ip_iterator) && index < count)
@@ -485,31 +520,13 @@ agent_iterator_authorized (iterator_t *iterator)
   return iterator_int (iterator, GET_ITERATOR_COLUMN_COUNT + 2);
 }
 
-/**
- * @brief Retrieve min_interval of current agent.
- */
-int
-agent_iterator_min_interval (iterator_t *iterator)
-{
-  return iterator_int (iterator, GET_ITERATOR_COLUMN_COUNT + 3);
-}
-
-/**
- * @brief Retrieve heartbeat_interval of current agent.
- */
-int
-agent_iterator_heartbeat_interval (iterator_t *iterator)
-{
-  return iterator_int (iterator, GET_ITERATOR_COLUMN_COUNT + 4);
-}
-
 /**
  * @brief Retrieve connection status string of current agent.
  */
 const char *
 agent_iterator_connection_status (iterator_t *iterator)
 {
-  return iterator_string (iterator, GET_ITERATOR_COLUMN_COUNT + 5);
+  return iterator_string (iterator, GET_ITERATOR_COLUMN_COUNT + 3);
 }
 
 /**
@@ -518,16 +535,25 @@ agent_iterator_connection_status (iterator_t *iterator)
 time_t
 agent_iterator_last_update (iterator_t *iterator)
 {
-  return iterator_int (iterator, GET_ITERATOR_COLUMN_COUNT + 6);
+  return iterator_int (iterator, GET_ITERATOR_COLUMN_COUNT + 4);
 }
 
 /**
- * @brief Retrieve schedule string of current agent.
+ * @brief Retrieve last update timestamp of current agent.
+ */
+time_t
+agent_iterator_last_updater_heartbeat (iterator_t *iterator)
+{
+  return iterator_int (iterator, GET_ITERATOR_COLUMN_COUNT + 5);
+}
+
+/**
+ * @brief Retrieve config string of current agent.
  */
 const char *
-agent_iterator_schedule (iterator_t *iterator)
+agent_iterator_config (iterator_t *iterator)
 {
-  return iterator_string (iterator, GET_ITERATOR_COLUMN_COUNT + 7);
+  return iterator_string (iterator, GET_ITERATOR_COLUMN_COUNT + 6);
 }
 
 /**
@@ -536,7 +562,52 @@ agent_iterator_schedule (iterator_t *iterator)
 scanner_t
 agent_iterator_scanner (iterator_t *iterator)
 {
-  return iterator_int (iterator, GET_ITERATOR_COLUMN_COUNT + 8);
+  return iterator_int (iterator, GET_ITERATOR_COLUMN_COUNT + 7);
+}
+
+/**
+ * @brief Retrieve updater version of current agent.
+ */
+const char *
+agent_iterator_updater_version (iterator_t *iterator)
+{
+  return iterator_string (iterator, GET_ITERATOR_COLUMN_COUNT + 8);
+}
+
+/**
+ * @brief Retrieve agent version of current agent.
+ */
+const char *
+agent_iterator_agent_version (iterator_t *iterator)
+{
+  return iterator_string (iterator, GET_ITERATOR_COLUMN_COUNT + 9);
+}
+
+/**
+ * @brief Retrieve operating system of current agent.
+ */
+const char *
+agent_iterator_operating_system (iterator_t *iterator)
+{
+  return iterator_string (iterator, GET_ITERATOR_COLUMN_COUNT + 10);
+}
+
+/**
+ * @brief Retrieve architecture system of current agent.
+ */
+const char *
+agent_iterator_architecture (iterator_t *iterator)
+{
+  return iterator_string (iterator, GET_ITERATOR_COLUMN_COUNT + 11);
+}
+
+/**
+ * @brief Retrieve latest update status of current agent.
+ */
+int
+agent_iterator_update_to_latest (iterator_t *iterator)
+{
+  return iterator_int (iterator, GET_ITERATOR_COLUMN_COUNT + 12);
 }
 
 /**
@@ -551,8 +622,7 @@ agent_count (const get_data_t *get)
   static const char *extra_columns[] = AGENT_ITERATOR_FILTER_COLUMNS;
   static column_t columns[] = AGENT_ITERATOR_COLUMNS;
 
-  return count ("agent", get, columns, NULL, extra_columns,
-                0, 0, 0, TRUE);
+  return count ("agent", get, columns, NULL, extra_columns, 0, 0, 0, TRUE);
 }
 
 /**
@@ -564,7 +634,7 @@ agent_count (const get_data_t *get)
 int
 agent_writable (agent_t agent)
 {
-  (void)agent;
+  (void) agent;
   return 1;
 }
 
@@ -581,7 +651,8 @@ agent_in_use (agent_t agent)
     "WITH usage_counts AS ("
     "  SELECT COUNT(*) AS count FROM agent_group_agents WHERE agent_id = %llu"
     "  UNION ALL "
-    "  SELECT COUNT(*) AS count FROM agent_group_agents_trash WHERE agent = %llu"
+    "  SELECT COUNT(*) AS count FROM agent_group_agents_trash WHERE agent = "
+    "%llu"
     ") "
     "SELECT SUM(count) FROM usage_counts;",
     agent, agent);
@@ -591,15 +662,16 @@ agent_in_use (agent_t agent)
  * @brief Delete agents and associated IPs using a filtered UUID list.
  *
  * Deletes agents from the database and their associated IPs.
- * If @p agent_uuids is provided and non-empty, only those agents will be deleted.
- * If @p agent_uuids is NULL or empty, and @p scanner is non-zero,
+ * If @p agent_uuids is provided and non-empty, only those agents will be
+ * deleted. If @p agent_uuids is NULL or empty, and @p scanner is non-zero,
  * deletes all agents associated with that scanner.
  *
  * @param[in] scanner     Optional scanner filter (0 to ignore).
  * @param[in] agent_uuids List of agent UUIDs to delete.
  */
 void
-delete_agents_by_scanner_and_uuids (scanner_t scanner, agent_uuid_list_t agent_uuids)
+delete_agents_by_scanner_and_uuids (scanner_t scanner,
+                                    agent_uuid_list_t agent_uuids)
 {
   GString *where_clause = g_string_new ("WHERE 1=1");
 
@@ -611,7 +683,8 @@ delete_agents_by_scanner_and_uuids (scanner_t scanner, agent_uuid_list_t agent_u
         {
           if (i > 0)
             g_string_append (where_clause, ", ");
-          g_string_append_printf (where_clause, "'%s'", agent_uuids->agent_uuids[i]);
+          g_string_append_printf (where_clause, "'%s'",
+                                  agent_uuids->agent_uuids[i]);
         }
 
       g_string_append (where_clause, ")");
@@ -625,15 +698,12 @@ delete_agents_by_scanner_and_uuids (scanner_t scanner, agent_uuid_list_t agent_u
   sql_begin_immediate ();
 
   // Delete associated IPs
-  sql (
-    "DELETE FROM agent_ip_addresses "
-    "WHERE agent_id IN (SELECT agent_id FROM agents %s);",
-    where_clause->str);
+  sql ("DELETE FROM agent_ip_addresses "
+       "WHERE agent_id IN (SELECT agent_id FROM agents %s);",
+       where_clause->str);
 
   // Delete agents
-  sql (
-    "DELETE FROM agents %s;",
-    where_clause->str);
+  sql ("DELETE FROM agents %s;", where_clause->str);
 
   sql_commit ();
 
@@ -663,10 +733,8 @@ update_agents_comment (agent_uuid_list_t agent_uuids, const gchar *new_comment)
 
   sql_begin_immediate ();
 
-  sql (
-    "UPDATE agents SET comment = '%s' WHERE uuid IN (%s);",
-    new_comment,
-    uuid_list->str);
+  sql ("UPDATE agents SET comment = '%s' WHERE uuid IN (%s);", new_comment,
+       uuid_list->str);
 
   sql_commit ();
 
@@ -685,33 +753,31 @@ update_agents_comment (agent_uuid_list_t agent_uuids, const gchar *new_comment)
  *         2 if scanner mismatch.
  */
 int
-agent_id_by_uuid_and_scanner (const gchar *agent_uuid,
-                              scanner_t scanner_id,
+agent_id_by_uuid_and_scanner (const gchar *agent_uuid, scanner_t scanner_id,
                               agent_t *agent_id_out)
 {
   g_return_val_if_fail (agent_uuid != NULL, 1);
   g_return_val_if_fail (agent_id_out != NULL, 1);
 
   // Get the agent ID with matching scanner
-  agent_t agent_id = sql_int64_0 (
-    "SELECT id FROM agents WHERE uuid = '%s' AND scanner = %llu;",
-    agent_uuid, scanner_id);
+  agent_t agent_id =
+    sql_int64_0 ("SELECT id FROM agents WHERE uuid = '%s' AND scanner = %llu;",
+                 agent_uuid, scanner_id);
 
   if (agent_id != 0)
-  {
-    *agent_id_out = agent_id;
-    return 0;  // success
-  }
+    {
+      *agent_id_out = agent_id;
+      return 0; // success
+    }
 
   // Check if agent exists but scanner doesn't match
-  agent_id = sql_int64_0 (
-    "SELECT id FROM agents WHERE uuid = '%s';",
-    agent_uuid);
+  agent_id =
+    sql_int64_0 ("SELECT id FROM agents WHERE uuid = '%s';", agent_uuid);
 
   if (agent_id != 0)
-    return 2;  // scanner mismatch
+    return 2; // scanner mismatch
 
-  return 1;  // agent not found
+  return 1; // agent not found
 }
 
 /**
@@ -730,24 +796,23 @@ agents_in_use (agent_uuid_list_t agent_uuids)
   GString *uuid_filter = g_string_new ("");
 
   for (int i = 0; i < agent_uuids->count; ++i)
-  {
-    if (i > 0)
-      g_string_append (uuid_filter, ", ");
-    g_string_append_printf (uuid_filter, "'%s'", agent_uuids->agent_uuids[i]);
-  }
+    {
+      if (i > 0)
+        g_string_append (uuid_filter, ", ");
+      g_string_append_printf (uuid_filter, "'%s'", agent_uuids->agent_uuids[i]);
+    }
 
-  int count = sql_int (
-    "WITH matching_agents AS ("
-    "  SELECT id FROM agents WHERE uuid IN (%s)"
-    ") "
-    "SELECT COUNT(*) FROM ("
-    "  SELECT agent_id AS id FROM agent_group_agents"
-    "  WHERE agent_id IN (SELECT id FROM matching_agents)"
-    "  UNION ALL "
-    "  SELECT agent AS id FROM agent_group_agents_trash"
-    "  WHERE agent IN (SELECT id FROM matching_agents)"
-    ") AS used_agents;",
-    uuid_filter->str);
+  int count = sql_int ("WITH matching_agents AS ("
+                       "  SELECT id FROM agents WHERE uuid IN (%s)"
+                       ") "
+                       "SELECT COUNT(*) FROM ("
+                       "  SELECT agent_id AS id FROM agent_group_agents"
+                       "  WHERE agent_id IN (SELECT id FROM matching_agents)"
+                       "  UNION ALL "
+                       "  SELECT agent AS id FROM agent_group_agents_trash"
+                       "  WHERE agent IN (SELECT id FROM matching_agents)"
+                       ") AS used_agents;",
+                       uuid_filter->str);
 
   g_string_free (uuid_filter, TRUE);
 
