@@ -26,6 +26,12 @@
 
 #include <gvm/base/hosts.h>
 
+#undef G_LOG_DOMAIN
+/**
+ * @brief GLib log domain.
+ */
+#define G_LOG_DOMAIN "md manage"
+
 /**
  * @file
  * @brief GVM management layer: Alert SQL
